# **Statistics** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 统计学模块集合
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.7-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/统计学-Statistics-black.svg)]()

### **数据分析部分**
#### [各种距离计算](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/statistics/distance): 距离计算模块,包含闵氏距离,马氏距离等
#### [相关系数](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/statistics/coefficient): 相关系数与相关系数矩阵计算模块,包含pearman相关系数,spearman相关系数等
#### [数据常用分析](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/statistics/analysis): 分析计算模块,包含中位数,众数,分位数,方差,标准差等
#### [数据降维](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/statistics/dr): 奇异值分解(SVD)、主成分分析(PCA)、因子分析(FA)、独立成分分析(ICA)等
#### [数据聚类](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/statistics/clustering)
#### [数学函数类](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/statistics/maths): 一些常见的数学函数


### 参考文档
[主成分分析](https://blog.csdn.net/program_developer/article/details/80632779)



***
[1]: https://blog.jtyoui.com